@@ -1,4 +1,4 @@
-__all__ = ['webservice', 'webquery', 'exceptions', 
+__all__ = ['webservice', 'webquery', 'exceptions',
            'wcat', 'wcated', 'googlebooks', 'isbndb',
            'WSHTTPError', 'WSURLError', 'WQDataNotFoundError',
            'WQServiceIsDownError', 'WPDataWrongShapeError'
@@ -11,5 +11,6 @@ from . import wcat
 from . import wcated
 from . import googlebooks
 from . import isbndb
-from .exceptions import (WSHTTPError, WSURLError, 
-       WQDataNotFoundError, WQServiceIsDownError, WPDataWrongShapeError)
+from .exceptions import (WSHTTPError, WSURLError,
+                         WQDataNotFoundError, WQServiceIsDownError,
+                         WPDataWrongShapeError)
